import Toast from '@vant/weapp/toast/toast';
const _Http = getApp().globalData.http;
const md5 = require("../../utils/md5");
const loginMsg = require("./modules/login");
Page({

    /**
     * 页面的初始数据
     */
    data: {
        isAgree: true,
        accountno: "",
        password: "",
        inputType: "password", //密码输入框类型
        focus: false,
        memory: true, //记忆
        disabled: true, //是否禁用
        loading: false, //登陆中
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
        /* 恢复缓存中保存的账号密码 */
        this.setData({
            ...wx.getStorageSync('loginMsg')
        })
        /* 验证登录条件 */
        this.allowOrNot()
    },
    /* 微信登录 */
    wechatLogin() {
        if (!this.data.isAgree) return Toast({
            message: '请阅读并勾选用户协议',
            position: 'bottom'
        });
        wx.login({
            success(res) {
                if (res.code) {
                    _Http.loginbywechat({
                        wechat_code: res.code,
                        "systemclient": "wechatsaletool"
                    }).then(res => {
                        if (res.code == 0) return wx.showToast({
                            title: res.msg,
                            icon: "none"
                        })
                        loginMsg.loginMsg(res);
                    })
                } else {
                    console.log('登录失败！' + res.errMsg)
                }
            }
        })
    },
    /* 用户登录 */
    userLogin() {
        if (this.data.loading || this.data.disabled) return;
        if (!this.data.isAgree) return Toast({
            message: '请阅读并勾选用户协议',
            position: 'bottom'
        });
        this.setData({
            loading: true
        })
        _Http.login({
            "accountno": this.data.accountno,
            "password": md5.hexMD5(this.data.password),
            "systemclient": "wechatsaletool"
        }).then(res => {
            this.setData({
                loading: false
            })
            if (res.msg != '成功') return wx.showToast({
                title: res.msg,
                icon: "none"
            })
            wx.setStorageSync('loginMsg', {
                accountno: this.data.accountno,
                password: (this.data.memory) ? this.data.password : ''
            })
            loginMsg.loginMsg(res);
        })
    },
    /* 改变密码输入框类型 */
    changePasswordType() {
        this.setData({
            inputType: this.data.inputType == "text" ? 'password' : 'text'
        })
    },
    /* 授权 */
    agreementChange({
        detail
    }) {
        this.setData({
            isAgree: detail
        })
    },
    /* 手机号 */
    inputPhone(e) {
        this.setData({
            accountno: e.detail.value.trim()
        })
        this.allowOrNot()
    },
    /* 密码 */
    inputPassword(e) {
        this.setData({
            password: e.detail.value.trim()
        })
        this.allowOrNot()
    },
    /* 验证是否允许登录 */
    allowOrNot() {
        this.setData({
            disabled: (this.data.accountno.length > 0 && this.data.password.length > 5) ? false : true
        })
    },
    /* 是否记忆密码 */
    isMemory() {
        this.setData({
            memory: !this.data.memory
        })
    },
})